

SIAQuery
=====================

.. currentmodule:: pyvo.dal.sia

.. autoclass:: SIAQuery
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~SIAQuery.allowed_intersects
      ~SIAQuery.dec
      ~SIAQuery.format
      ~SIAQuery.intersect
      ~SIAQuery.pos
      ~SIAQuery.ra
      ~SIAQuery.size
      ~SIAQuery.std_parameters
      ~SIAQuery.verbosity

   
   

   
   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: allowed_intersects
   .. autoattribute:: dec
   .. autoattribute:: format
   .. autoattribute:: intersect
   .. autoattribute:: pos
   .. autoattribute:: ra
   .. autoattribute:: size
   .. autoattribute:: std_parameters
   .. autoattribute:: verbosity

   
   

   
   
   